==> ui-framework-4.6.2-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractItemMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractItemMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, io.intino.alexandria.ui.documentation.Item, B> {
	public Col_6_1_0153585989 col_6_1_0153585989;
	public ItemMold.Col_6_1_0153585989. Avatar avatar;
	public ItemMold.Col_6_1_0153585989. Label label;

    public AbstractItemMold(B box) {
        super(box);
        id("itemMold");
    }

    @Override
	public void init() {
		super.init();
		if (col_6_1_0153585989 == null) col_6_1_0153585989 = register(new Col_6_1_0153585989(box()).<Col_6_1_0153585989>id("a_433307856").owner(AbstractItemMold.this));
		if (col_6_1_0153585989 != null) avatar = col_6_1_0153585989.avatar;
		if (col_6_1_0153585989 != null) label = col_6_1_0153585989.label;
	}

	public class Col_6_1_0153585989 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ItemMold.Col_6_1_0153585989. Avatar avatar;
		public ItemMold.Col_6_1_0153585989. Label label;

		public Col_6_1_0153585989(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (avatar == null) avatar = register(new Avatar(box()).<Avatar>id("a_1928025295").owner(AbstractItemMold.this));
			if (label == null) label = register(new Label(box()).<Label>id("a1055717916").owner(AbstractItemMold.this));
		}

		public class Avatar extends io.intino.alexandria.ui.displays.components.ImageAvatar<io.intino.alexandria.ui.displays.notifiers.ImageAvatarNotifier, B>  {

			public Avatar(B box) {
				super(box);
				_text("");
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Label(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> ui-framework-4.14.8-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractItemMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractItemMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, io.intino.alexandria.ui.documentation.Item, B> {
	public _6_1_0153585989 _6_1_0153585989;
	public ItemMold._6_1_0153585989. Avatar avatar;
	public ItemMold._6_1_0153585989. Label label;

    public AbstractItemMold(B box) {
        super(box);
        id("itemMold");
    }

    @Override
	public void init() {
		super.init();
		if (_6_1_0153585989 == null) _6_1_0153585989 = register(new _6_1_0153585989(box()).<_6_1_0153585989>id("a1211036330").owner(AbstractItemMold.this));
		if (_6_1_0153585989 != null) avatar = _6_1_0153585989.avatar;
		if (_6_1_0153585989 != null) label = _6_1_0153585989.label;
	}

	public class _6_1_0153585989 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public ItemMold._6_1_0153585989. Avatar avatar;
		public ItemMold._6_1_0153585989. Label label;

		public _6_1_0153585989(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (avatar == null) avatar = register(new Avatar(box()).<Avatar>id("a_1928025295").owner(AbstractItemMold.this));
			if (label == null) label = register(new Label(box()).<Label>id("a1055717916").owner(AbstractItemMold.this));
		}

		public class Avatar extends io.intino.alexandria.ui.displays.components.ImageAvatar<io.intino.alexandria.ui.displays.notifiers.ImageAvatarNotifier, B>  {

			public Avatar(B box) {
				super(box);
				_text("");
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Label(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}
